@@ -84,6 +84,8 @@ def parse_toml():
             args["metadata"] = pd.read_csv(meta_path)
         elif meta_path.suffix == ".parquet":
             args["metadata"] = pd.read_parquet(meta_path)
+        elif meta_path.suffix == ".jsonl":
+            args["metadata"] = pd.read_json(meta_path, lines=True)
         else:
             print("Extension of " + meta_path.suffix + " not one of .csv or .parquet")
             sys.exit(1)
@@ -150,9 +152,6 @@ def parse_args(args: ZenoParameters, base_path) -> ZenoParameters:
     if args.label_path != "":
         args.label_path = os.path.realpath(os.path.join(base_path, args.label_path))
 
-    if args.data_column != "" and args.id_column == "":
-        args.id_column = args.data_column
-
     return args
 
 
